Learn R Programming

cSEM (version 0.7.1)

calculateCorVCV: Internal: Distribution-free asymptotic variance-covariance matrix of correlations

Description

Large-sample variance-covariance matrix of the unique sample correlations of the columns of .X, using the estimator of Steiger1982;textualcSEM.

Usage

calculateCorVCV(.X)

Value

The (L x L) asymptotic variance-covariance matrix of the correlations, L = P(P - 1)/2, in lower-triangular order.

Arguments

.X

A matrix of processed data (scaled, cleaned and ordered).

Details

The correlations are taken in lower-triangular order of the correlation matrix of .X, the same order used by the HTMT gradient, so that a gradient vector and this matrix align by position for a delta-method confidence interval, i.e. Var(f) = t(g) %*% calculateCorVCV(.X) %*% g.

References