Learn R Programming

cSEM (version 0.7.1)

checkIsolatedConstruct: Internal: Check whether constructs in the structural model are isolated

Description

Internal: Check whether constructs in the structural model are isolated

Usage

checkIsolatedConstruct(.matrix)

Arguments

Value

logical: 'TRUE': Isolated; 'FALSE':connected to at least one variable via a path.