Learn R Programming

cSEM (version 0.7.1)

polychor: Internal: Fast polychoric correlation

Description

Estimate the polychoric correlation between two ordinal (categorical) variables x and y, i.e., the correlation between the two continuous, bivariate normal latent variables assumed to underlie x and y Drasgow1988cSEM. Implemented by Kjell S. Slupphaug.

Usage

polychor(
  x,
  y,
  control = list(),
  maxrho = 0.999,
  start = NULL,
  thresholds = FALSE
)

Arguments

References