Learn R Programming

cSEM (version 0.7.1)

LeDang2022: Data: LeDang2022

Description

A data frame of 107 variables and 773 participants. Labelled factors were converted from numerical to character representation through haven::as_factor(). The provided data frame is a fusion of the converted labelled factors for the demographic data and the unconverted Likert scale data for the psychometric data.

Usage

LeDang2022

Arguments

Format

An object of class data.frame with 773 rows and 107 columns.

Details

This data is based on self-report surveys collected from graduates of universities in Northern Vietnam Le2022cSEM. The data has been used to analyze the relationship between measures of HEXACO personality traits and two job-search outcomes: (1) number of job interviews; and (2) job offers through job search networking behavior Le2022cSEM.

The data were also analyzed using Integrated-Generalized Structured Component Analysis (IGSCA) in GSCAPro Hwang2021acSEM.

References