calculateFitness: Internal: Function that calculates the fitness value
Description
Function that calculates the fitness value of a model.
This function adheres to the necessary requirements for a function to be supplied to ga.
Usage
calculateFitness(
.matrix_vector,
.data,
.model_org,
.only_structural,
.ms_criterion,
.fbar
)