checkIsolatedConstruct: Internal: Check whether constructs in the structural model are isolated
Description
Internal: Check whether constructs in the structural model are isolated
Usage
checkIsolatedConstruct(.matrix)
Value
logical: 'TRUE': Isolated; 'FALSE':connected to at least one variable via a path.