Removes those elements of a list of permutation (or resample) test statistics
that contain at least one NA or NaN anywhere in their structure, including
inside nested lists.
dropNAResamples(.ref_dist = NULL)A list containing only those elements of .ref_dist that are free of
NA and NaN. Names and relative order are preserved.
A list of test statistics, one element per permutation run.
Elements that are the literal NA sentinel (written when a permutation run is
inadmissible and .handle_inadmissibles = "drop") are removed as well.