polyserial: Internal: Fast polyserial correlation
Description
Estimate the polyserial correlation between a continuous variable x
and an ordinal (categorical) variable y, i.e., the correlation between
x and the continuous latent variable assumed to underlie y
Drasgow1988cSEM. Implemented by Kjell S. Slupphaug.
Usage
polyserial(
x,
y,
control = list(),
maxrho = 0.999,
start = NULL,
thresholds = FALSE
)